@@ -4,28 +4,19 @@
  */
 
 #pragma once
-#include <aws/s3-crt/S3Crt_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/s3-crt/S3Crt_EXPORTS.h>
 
-namespace Aws
-{
-namespace S3Crt
-{
-namespace Model
-{
-  enum class BucketAccelerateStatus
-  {
-    NOT_SET,
-    Enabled,
-    Suspended
-  };
+namespace Aws {
+namespace S3Crt {
+namespace Model {
+enum class BucketAccelerateStatus { NOT_SET, Enabled, Suspended };
 
-namespace BucketAccelerateStatusMapper
-{
+namespace BucketAccelerateStatusMapper {
 AWS_S3CRT_API BucketAccelerateStatus GetBucketAccelerateStatusForName(const Aws::String& name);
 
 AWS_S3CRT_API Aws::String GetNameForBucketAccelerateStatus(BucketAccelerateStatus value);
-} // namespace BucketAccelerateStatusMapper
-} // namespace Model
-} // namespace S3Crt
-} // namespace Aws
+}  // namespace BucketAccelerateStatusMapper
+}  // namespace Model
+}  // namespace S3Crt
+}  // namespace Aws
